pub struct Mesh {
pub rotation: Vector3,
pub position: Vector3,
pub scale: Vector3,
pub char: char,
/* private fields */
}Expand description
A struct containing all the data for a mesh. Rotation, as with everything in this crate, is in radians, with each value determining the amount that the mesh should be rotated around the given axis. Note that vertices are stored on a hashmap, not a vector.
Fields
rotation: Vector3position: Vector3scale: Vector3char: charImplementations
Sourceimpl Mesh
impl Mesh
pub fn insert_vertex( &mut self, index: usize, vertex: Vector3, ) -> Option<Vector3>
pub fn get_vertex(&mut self, index: usize) -> Option<Vector3>
pub fn insert_vertices( &mut self, vertices: Vec<(usize, Vector3)>, ) -> Vec<(usize, Option<Vector3>)>
pub fn remove_vertex(&mut self, index: usize) -> Option<Vector3>
pub fn get_verticies(&self) -> &HashMap<usize, Vector3>
pub fn get_verticies_mut(&mut self) -> &mut HashMap<usize, Vector3>
pub fn add_edge(&mut self, edge: (usize, usize))
pub fn add_edges(&mut self, edges: Vec<(usize, usize)>)
pub fn remove_edge(&mut self, edge: (usize, usize)) -> Option<(usize, usize)>
pub fn get_edges(&self) -> &Vec<(usize, usize)>
pub fn get_edges_mut(&mut self) -> &mut Vec<(usize, usize)>
pub fn get_global_verticies(&self) -> HashMap<usize, Vector3>
Sourcepub fn recenter(&mut self) -> Vector3
pub fn recenter(&mut self) -> Vector3
Gets the average position of all the vertices and centers the mesh to be centered around that point. Good for meshes you want to rotate. returns the global coords to where the mesh was previously centered. If the mesh’s position is set to this, then the mesh will go back to it’s previous position, only now it’s center is appropriatly placed so rotation won’t look broken. EX:
let new_position = my_mesh.recenter();
my_mesh.position = new_position;Trait Implementations